Class: Yookassa::Deal
- Inherits:
-
ResourceShortcut
- Object
- ResourceShortcut
- Yookassa::Deal
- Defined in:
- lib/yookassarb.rb
Overview
Convenience wrapper for deal operations via the default client.
Convenience wrapper for deal operations via the default client.