Class: Yookassa::Receipt
- Inherits:
-
ResourceShortcut
- Object
- ResourceShortcut
- Yookassa::Receipt
- Defined in:
- lib/yookassarb.rb
Overview
Convenience wrapper for receipt operations via the default client.
Convenience wrapper for receipt operations via the default client.