Class: Yookassa::Refund
- Inherits:
-
ResourceShortcut
- Object
- ResourceShortcut
- Yookassa::Refund
- Defined in:
- lib/yookassarb.rb
Overview
Convenience wrapper for refund operations via the default client.
Convenience wrapper for refund operations via the default client.